@@ -1,11 +1,13 @@
 <?php
 require_once 'confusa_include.php';
-require_once 'framework.php';
-require_once 'person.php';
+require_once 'Content_Page.php';
+require_once 'Framework.php';
+require_once 'Person.php';
 require_once 'send_element.php';
 require_once 'csv_lib.php';
-require_once 'input.php';
-require_once 'mdb2_wrapper.php';
+require_once 'Input.php';
+require_once 'MDB2Wrapper.php';
+require_once 'CS.php';
 
 class CP_RevokeCertificate extends Content_Page
 {
@@ -130,6 +132,20 @@ class CP_RevokeCertificate extends Content_Page
 
 	public function process()
 	{
+
+		$subscriber = $this->person->getSubscriber();
+
+		if (empty($subscriber) || !$subscriber->isSubscribed()) {
+			$this->tpl->assign('not_subscribed_header',
+					   $this->translateTag('l10n_not_sub_header', 'messages'));
+			$this->tpl->assign('not_subscribed_1',
+					   $this->translateTag('l10n_not_sub_1', 'messages'));
+			$this->tpl->assign('not_subscribed_2',
+					   $this->translateTag('l10n_not_sub_2', 'messages'));
+			$this->tpl->assign('content', $this->tpl->fetch('errors/unsubscribed.tpl'));
+			return;
+		}
+
 		try {
 			if ($this->person->inAdminMode()) {
 				$this->showAdminRevokeTable();
@@ -145,7 +161,7 @@ class CP_RevokeCertificate extends Content_Page
 
 		} catch (ConfusaGenException $cge) {
 			Framework::error_output("Can not display revocation options! Server " .
-									"said: " . htmlentities($cge->getMessage()));
+									"said: " . $cge->getMessage());
 		}
 	}
 
@@ -154,8 +170,8 @@ class CP_RevokeCertificate extends Content_Page
 	 *
 	 * For NREN admins it is planned to restrict the permission to revoke to an
 	 * incident response team. Revocation can either take place
-	 * by a wildcard-search for an ePPN or by uplading a CSV with ePPNs which
-	 * will be searched wrapped into wildcards
+	 * by a wildcard-search for an ePPN or by uplading a CSV with ePPNs (or other
+	 * unique identifiers) which will be searched wrapped into wildcards
 	 */
 	private function showAdminRevokeTable()
 	{
@@ -280,10 +296,8 @@ class CP_RevokeCertificate extends Content_Page
 	 * set of her own certificates.
 	 */
 	 private function showNonAdminRevokeTable()
-	{
-		if (isset($_SESSION['auth_keys'])) {
-			unset($_SESSION['auth_keys']);
-		}
+	 {
+		 CS::deleteSessionKey('auth_keys');
 
 		$eppn = $this->person->getEPPN();
 		$certs = $this->ca->getCertListForEPPN($eppn, $this->person->getSubscriber()->getOrgName());
@@ -296,7 +310,7 @@ class CP_RevokeCertificate extends Content_Page
 
 		/* total number of occurences for every owner */
 		$stats = array_count_values($owners);
-		$_SESSION['auth_keys'] = $orders;
+		CS::setSessionKey('auth_keys',$orders);
 		$owners = array_unique($owners);
 		$this->tpl->assign('owners', $owners);
 		$this->tpl->assign('stats', $stats);
@@ -326,10 +340,7 @@ class CP_RevokeCertificate extends Content_Page
 	 */
 	private function searchCertsDisplay($common_name, $subscriber)
 	{
-		if (isset($_SESSION['auth_keys'])) {
-			unset($_SESSION['auth_keys']);
-		}
-
+		CS::deleteSessionKey('auth_keys');
 		if (!empty($subscriber)) {
 			$certs = $this->ca->getCertListForPersons($common_name, $subscriber);
 		}
@@ -351,7 +362,7 @@ class CP_RevokeCertificate extends Content_Page
 
 			/* total number of occurences for every owner */
 			$stats = array_count_values($owners);
-			$_SESSION['auth_keys'] = $orders;
+			CS::setSessionKey('auth_keys', $orders);
 			$owners = array_unique($owners);
 			$this->tpl->assign('owners', $owners);
 			$this->tpl->assign('stats', $stats);
@@ -382,16 +393,14 @@ class CP_RevokeCertificate extends Content_Page
 		    Config::get_config('capi_test') === true) {
 			Framework::message_output($this->translateTag('l10n_msg_revsim1', 'revocation'));
 		}
-		$auth_keys = array();
-
-		if (isset($_SESSION['auth_keys'])) {
-			$auth_keys = $_SESSION['auth_keys'];
-			unset($_SESSION['auth_keys']);
-		} else {
+		$auth_keys = CS::getSessionKey('auth_keys');
+		CS::deleteSessionKey('auth_keys');
+		if (is_null($auth_keys)) {
 			Framework::error_output("Lost the certificate identifiers associated with " .
 			                        "common name " .
 			                        htmlentities($common_name) .
 			                        " during the session! Please try again!");
+			return;
 		}
 		if (!array_key_exists($common_name, $auth_keys)) {
 			Framework::error_output("Auth-keys has no such common-name ($common_name). Cannot continue.");
@@ -447,13 +456,12 @@ class CP_RevokeCertificate extends Content_Page
 			Framework::message_output($this->translateTag('l10n_msg_revsim1', 'revocation'));
 		}
 
-		$auth_keys = array();
-		if (isset($_SESSION['auth_keys'])) {
-			$auth_keys = $_SESSION['auth_keys'];
-			unset($_SESSION['auth_keys']);
-		} else {
+		$auth_keys = CS::getSessionKey('auth_keys');
+		CS::deleteSessionKey('auth_keys');
+		if (is_null($auth_keys)) {
 			Framework::error_output("Lost session! Please log-out of Confusa, " .
-									"log-in again and try again!\n");
+						"log-in again and try again!\n");
+			return;
 		}
 
 		$num_certs = count($auth_keys);
@@ -491,11 +499,11 @@ class CP_RevokeCertificate extends Content_Page
 
 	/**
 	 * Display a list of distinguished names whose certificates will be revoked
-	 * based on an uploaded CSV with a list of eduPersonPrincipalNames. Offer the
+	 * based on an uploaded CSV with a list of UIDs (e.g. eppns). Offer the
 	 * possibility to revoke these certificates.
 	 *
 	 * @param $eppn_file string The name of the $_FILES parameter containining the
-	 *                          CSV of eduPersonPrincipalNames
+	 *                          CSV of unique identifiers
 	 * @param $subscriber string The name of the subscriber by which the search is
 	 * 							scoped
 	 *
@@ -508,9 +516,7 @@ class CP_RevokeCertificate extends Content_Page
 		 * an endless list of auth_keys as hidden parameters
 		 * to the user and then from there back again with a POST to the server
 		 */
-		if (isset($_SESSION['auth_keys'])) {
-			unset($_SESSION['auth_keys']);
-		}
+		CS::deleteSessionKey('auth_keys');
 
 		$csvl = new CSV_Lib($eppn_file);
 		$eppn_list = $csvl->get_csv_entries();
@@ -533,7 +539,7 @@ class CP_RevokeCertificate extends Content_Page
 			}
 
 			$owners = array_unique($owners);
-			$_SESSION['auth_keys'] = $auth_keys;
+			CS::setSessionKey('auth_keys', $auth_keys);
 			$this->tpl->assign('owners', $owners);
 			$this->tpl->assign('revoke_list', true);
 			$this->tpl->assign('nren_reasons', ConfusaConstants::$REVOCATION_REASONS);
